@@ -12,9 +12,19 @@ from ..bedrock.atoms import (
     Table,
     get_index_cls_name,
 )
-from ..bedrock.feature_types import ANY_FEATURE_TYPE, ForeignKey
+from ..bedrock.feature_types import (
+    ANY_FEATURE_TYPE,
+    ForeignKey,
+    PrimitiveFeature,
+)
 from ..bedrock.namespace_metadata import NamespaceMetadata
-from .bases import BaseEntity, CompositeTypeBase, IndexBase, TableFeaturesBase
+from .bases import (
+    BaseEntity,
+    CompositeTypeBase,
+    IndexBase,
+    Nullable,
+    TableFeaturesBase,
+)
 from .scrutable import TableFactory
 
 
@@ -103,7 +113,7 @@ class ScriptWriter:
         return cls_name
 
     def _add_table_index_cls(self, table: Table):
-        if table.index is None:
+        if not table.index:
             return
         cls_name = table.index_cls_id
         self._add_feat_list_as_cls(table.index, cls_name, IndexBase)
@@ -169,7 +179,11 @@ class ScriptWriter:
                 full_id.obj_id in PrimitiveType.__members__
             ):
                 deps.append(full_id.datascript_obj_accessor)
-            att_dic[feat.prime_id] = full_id.datascript_obj_accessor
+            ds_obj_accessor = full_id.datascript_obj_accessor
+            if isinstance(feat, PrimitiveFeature) and feat.nullable:
+                ds_obj_accessor = f"{Nullable.__name__}({ds_obj_accessor})"
+                self.ssc_imports.add(Nullable)
+            att_dic[feat.prime_id] = ds_obj_accessor
         return deps, att_dic
 
     def _add_cls_def(self, cls_name, parent_names, deps, att_dict=None):
