@@ -15,7 +15,7 @@ def class_def_from_cls(cls: Type):
 def get_class_def(
     cls_name: str, parent_names: List[str] = None, att_dict: dict = None
 ):
-    parent_str = ", ".join(parent_names or [])
+    parent_str = ", ".join(parent_names)
 
     if att_dict:
         att_strs = [f"   {k} = {v}" for k, v in att_dict.items()]
